import unittest

import src.hkkang_utils.string as string_utils


class Test_string_utils(unittest.TestCase):
    def __init__(self, *args, **kwargs):
        super(Test_string_utils, self).__init__(*args, **kwargs)
    
    def test_multi_space_to_single_space(self):
        pass
    
    def test_is_int(self):
        pass
    
    def test_is_number(self):
        pass


if __name__ == "__main__":
    unittest.main()
